==> mobiusft-1.30.zip: mobiusft-1.30/src/python/pymobius/p2p/emuletorrent/decoder_ed2k_fastresume.py <==
#!/usr/bin/env python
# =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
# Mobius Forensic Toolkit
# Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022 Eduardo Aguiar
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
# Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
# =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
import mobius
import binascii
import pymobius.p2p.bittorrent.decoder_btencode

# =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
# @brief Entry
# =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
class Entry (object):
  pass

# =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
# @brief Decode data from *.fastresume file
# =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
def decode (f):

  # try to open file
  reader = f.new_reader ()
  if not reader:
    return

  # decode header
  decoder = mobius.decoder.data_decoder (reader)

  entry = Entry ()
  entry.hash_ed2k = binascii.hexlify (decoder.get_bytearray_by_size (16))
  
  siz = decoder.get_uint16_le ()
  entry.path = decoder.get_string_by_size (siz).replace ('/', '\\')
  entry.size = decoder.get_uint64_le ()
  entry.dummy = decoder.get_uint32_le ()
  entry.fastresume_path = f.path.replace ('/', '\\')
  entry.fastresume_creation_time = f.creation_time
  entry.fastresume_last_modification_time = f.modification_time

  # set filename
  if '\\' in entry.path:
    entry.name = entry.path.rsplit ('\\', 1)[1]
  else:
    entry.name = entry.path

  # decode BTEncode metadata
  siz = decoder.get_uint32_le ()
  metadata_block = decoder.get_string_by_size (siz)
  entry.metadata = pymobius.p2p.bittorrent.decoder_btencode.decode (metadata_block)
  
  # return entry
  return entry

==> mobiusft-1.31.zip: mobiusft-1.31/src/python/pymobius/p2p/emuletorrent/decoder_ed2k_fastresume.py <==
# =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
# Mobius Forensic Toolkit
# Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022 Eduardo Aguiar
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of the GNU General Public License as published by the
# Free Software Foundation; either version 2, or (at your option) any later
# version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General
# Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program. If not, see <http://www.gnu.org/licenses/>.
# =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
import mobius
import pymobius.p2p.bittorrent.decoder_btencode

# =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
# @brief Entry
# =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
class Entry (object):
  pass

# =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
# @brief Decode data from *.fastresume file
# =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
def decode (f):

  # try to open file
  reader = f.new_reader ()
  if not reader:
    return

  # decode header
  decoder = mobius.decoder.data_decoder (reader)

  entry = Entry ()
  entry.hash_ed2k = mobius.encoder.hexstring (decoder.get_bytearray_by_size (16))

  siz = decoder.get_uint16_le ()
  entry.path = decoder.get_string_by_size (siz).replace ('/', '\\')
  entry.size = decoder.get_uint64_le ()
  entry.dummy = decoder.get_uint32_le ()
  entry.fastresume_path = f.path.replace ('/', '\\')
  entry.fastresume_creation_time = f.creation_time
  entry.fastresume_last_modification_time = f.modification_time

  # set filename
  if '\\' in entry.path:
    entry.name = entry.path.rsplit ('\\', 1)[1]
  else:
    entry.name = entry.path

  # decode BTEncode metadata
  siz = decoder.get_uint32_le ()
  metadata_block = decoder.get_string_by_size (siz)
  entry.metadata = pymobius.p2p.bittorrent.decoder_btencode.decode (metadata_block)

  # return entry
  return entry
